@@ -19,18 +19,20 @@
  */
 
 #include "filefetchjob.h"
+#include "filemetadatautil_p.h"
 
+#include <QFileInfo>
 #include <QTimer>
 #include <Baloo/File>
 
 #include <KFileMetaData/UserMetaData>
-#include <KFileMetaData/PropertyInfo>
 
 using namespace Baloo;
 
-FileFetchJob::FileFetchJob(const QStringList& urls, QObject* parent)
+FileFetchJob::FileFetchJob(const QStringList& urls, bool canEditAll, QObject* parent)
     : KJob(parent)
     , m_urls(urls)
+    , m_canEditAll(canEditAll)
 {
 }
 
@@ -39,45 +41,25 @@ void FileFetchJob::start()
     QTimer::singleShot(0, this, SLOT(doStart()));
 }
 
-static QVariantMap convertPropertyMap(const KFileMetaData::PropertyMap& propMap)
-{
-    QVariantMap map;
-    KFileMetaData::PropertyMap::const_iterator it = propMap.constBegin();
-    for (; it != propMap.constEnd(); it++) {
-        KFileMetaData::PropertyInfo pi(it.key());
-        map.insertMulti(pi.name(), it.value());
-    }
-
-    return map;
-}
-
 void FileFetchJob::doStart()
 {
     for (const QString& filePath : m_urls) {
         Baloo::File file(filePath);
         file.load();
 
-        QVariantMap prop = convertPropertyMap(file.properties());
+        QVariantMap prop = Baloo::Private::toNamedVariantMap(file.properties());
+        KFileMetaData::UserMetaData umd(filePath);
 
-        KFileMetaData::UserMetaData md(filePath);
-        QStringList tags = md.tags();
-        if (!tags.isEmpty()) {
-            prop.insert("tags", tags);
+        if (umd.isSupported()) {
+            // FIXME - check writable
+
+            QVariantMap attributes = Baloo::Private::convertUserMetaData(umd);
+            prop.unite(attributes);
+        } else {
+            m_canEditAll = false;
         }
-
-        int rating = md.rating();
-        if (rating) {
-            prop.insert("rating", rating);
-        }
-
-        QString comment = md.userComment();
-        if (!comment.isEmpty()) {
-            prop.insert("userComment", comment);
-        }
-
-        const QString originUrl = md.originUrl().toDisplayString();
-        if (!originUrl.isEmpty()) {
-            prop.insert("originUrl", originUrl);
+        if (m_canEditAll) {
+            m_canEditAll = QFileInfo(filePath).isWritable();
         }
 
         m_data << prop;
@@ -90,3 +72,8 @@ QList<QVariantMap>  Baloo::FileFetchJob::data() const
 {
     return m_data;
 }
+
+bool FileFetchJob::canEditAll() const
+{
+    return m_canEditAll;
+}
